=== modified file 'check_blockers.py'
--- check_blockers.py	2016-08-23 13:49:03 +0000
+++ check_blockers.py	2016-08-23 14:09:03 +0000
@@ -133,6 +133,9 @@
     """Update the critical blocker+ci bugs for the branch to Fix Released."""
     changes = []
     for bug_id, bug_task in bugs.items():
+        if 'intermittent-failure' in bug_task.bug.tags:
+            changes.append('Skipping intermittent-failure %s' % bug_task.title)
+            continue
         changes.append('Updated %s' % bug_task.title)
         bug_task.status = 'Fix Released'
         if not dry_run:

=== modified file 'tests/test_check_blockers.py'
--- tests/test_check_blockers.py	2016-08-23 13:49:03 +0000
+++ tests/test_check_blockers.py	2016-08-23 14:09:03 +0000
@@ -16,13 +16,15 @@
     ]}
 
 
-def make_fake_lp(series=False, bugs=False, project_name='juju'):
+def make_fake_lp(series=False, bugs=False, project_name='juju', tags=[]):
     """Return a fake Lp lib object based on Mocks"""
     if bugs:
         task_1 = Mock(
             self_link='https://lp/j/98765', title='one', status='Triaged')
+        task_1.bug.tags = tags
         task_2 = Mock(
             self_link='https://lp/j/54321', title='two', status='Triaged')
+        task_2.bug.tags = tags
         bugs = [task_1, task_2]
     else:
         bugs = []
@@ -121,7 +123,7 @@
         self.assertEqual(0, code)
 
     def test_get_lp_bugs_with_master_branch(self):
-        lp = make_fake_lp(series=False, bugs=True)
+        lp = make_fake_lp(series=False, bugs=True, tags=['blocker'])
         bugs = check_blockers.get_lp_bugs(lp, 'master', ['blocker'])
         self.assertEqual(['54321', '98765'], sorted(bugs.keys()))
         project = lp.projects['juju']
@@ -132,7 +134,8 @@
             tags=check_blockers.BUG_TAGS, tags_combinator='All')
 
     def test_get_lp_bugs_with_supported_branch(self):
-        lp = make_fake_lp(series=True, bugs=True, project_name='juju-core')
+        lp = make_fake_lp(series=True, bugs=True,
+                          project_name='juju-core', tags=['blocker'])
         bugs = check_blockers.get_lp_bugs(lp, '1.20', ['blocker'])
         self.assertEqual(['54321', '98765'], sorted(bugs.keys()))
         project = lp.projects['juju-core']
@@ -251,7 +254,7 @@
             self.assertEqual(json, {"result": []})
 
     def test_update_bugs(self):
-        lp = make_fake_lp(series=False, bugs=True)
+        lp = make_fake_lp(series=False, bugs=True, tags=['blocker'])
         bugs = check_blockers.get_lp_bugs(lp, 'master', ['blocker'])
         code, changes = check_blockers.update_bugs(
             bugs, 'master', '1234', dry_run=False)
@@ -266,6 +269,18 @@
         bugs['54321'].bug.newMessage.assert_called_with(
             subject=expected_subject, content=expected_content)
 
+    def test_update_bugs_skipped(self):
+        lp = make_fake_lp(
+            series=False, bugs=True, tags=['blocker', 'intermittent-failure'])
+        bugs = check_blockers.get_lp_bugs(lp, 'master', ['blocker'])
+        code, changes = check_blockers.update_bugs(
+            bugs, 'master', '1234', dry_run=False)
+        self.assertEqual(0, code)
+        self.assertIn('Skipping intermittent-failure', changes)
+        self.assertEqual('Triaged', bugs['54321'].status)
+        self.assertEqual(0, bugs['54321'].lp_save.call_count)
+        self.assertEqual(0, bugs['54321'].bug.newMessage.call_count)
+
     def test_update_bugs_with_dry_run(self):
         lp = make_fake_lp(series=False, bugs=True)
         bugs = check_blockers.get_lp_bugs(lp, 'master', ['blocker'])

